.. SPDX-FileCopyrightText: Copyright © 2025 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _fairical.api:

============
 Python API
============

This section includes information for using the Python API of
``fairical``.


.. autosummary::
   :toctree: api
   :recursive:

   fairical


.. include:: links.rst
